@@ -18,18 +18,42 @@ limitations under the License.
 package models
 
 import (
+	"encoding/json"
+
 	"github.com/apache/incubator-devlake/models/common"
+	"github.com/apache/incubator-devlake/plugins/core"
 	"gorm.io/datatypes"
 )
 
+const BLUEPRINT_MODE_NORMAL = "NORMAL"
+const BLUEPRINT_MODE_ADVANCED = "ADVANCED"
+
 type Blueprint struct {
 	Name       string         `json:"name" validate:"required"`
-	Tasks      datatypes.JSON `json:"tasks" validate:"required"`
+	Mode       string         `json:"mode" gorm:"varchar(20)" validate:"required,oneof=NORMAL ADVANCED"`
+	Plan       datatypes.JSON `json:"plan"`
 	Enable     bool           `json:"enable"`
-	CronConfig string         `json:"cronConfig" validate:"required"`
+	CronConfig string         `json:"cronConfig"`
+	IsManual   bool           `json:"isManual"`
+	Settings   datatypes.JSON `json:"settings"`
 	common.Model
 }
 
 func (Blueprint) TableName() string {
 	return "_devlake_blueprints"
 }
+
+type BlueprintSettings struct {
+	Version     string          `json:"version" validate:"required,semver,oneof=1.0.0"`
+	Connections json.RawMessage `json:"connections" validate:"required"`
+}
+
+// UnmarshalPlan unmarshals Plan in JSON to strong-typed core.PipelinePlan
+func (bp *Blueprint) UnmarshalPlan() (core.PipelinePlan, error) {
+		var plan core.PipelinePlan
+		err := json.Unmarshal(bp.Plan, &plan)
+		if err != nil {
+			return nil, err
+		}
+		return plan, nil
+}
