@@ -30,4 +30,11 @@ type PullRequestComment struct {
 	CreatedDate   time.Time
 	CommitSha     string `gorm:"type:varchar(255)"`
 	Position      int
+	Type          string `gorm:"type:varchar(255)"`
+	ReviewId      string `gorm:"type:varchar(255)"`
+	Status        string `gorm:"type:varchar(255)"`
+}
+
+func (PullRequestComment) TableName() string {
+	return "pull_request_comments"
 }
