@@ -21,3 +21,7 @@ type BoardRepo struct {
 	BoardId string `gorm:"primaryKey;type:varchar(255)"`
 	RepoId  string `gorm:"primaryKey;type:varchar(255)"`
 }
+
+func (BoardRepo) TableName() string {
+	return "board_repos"
+}
