@@ -19,13 +19,17 @@ package migrationscripts
 
 import "github.com/apache/incubator-devlake/migration"
 
-// RegisterAll register all the migration scripts of framework
-func RegisterAll() {
-	migration.Register([]migration.Script{
-		new(initSchemas),
-		new(updateSchemas20220505), new(updateSchemas20220507), new(updateSchemas20220510),
-		new(updateSchemas20220513), new(updateSchemas20220524), new(updateSchemas20220526),
-		new(updateSchemas20220527), new(updateSchemas20220528), new(updateSchemas20220602),
-		new(updateSchemas2022061402),
-	}, "Framework")
+// All return all the migration scripts of framework
+func All() []migration.Script {
+	return []migration.Script{
+		new(addFrameTables),
+		new(renameStepToStage),
+		new(addSubtasksField),
+		new(updateBlueprintMode),
+		new(renameTasksToPlan),
+		new(addDomainTables),
+		new(addTypeField),
+		new(commitfileComponent),
+		new(removeNotes),
+	}
 }
