@@ -20,8 +20,8 @@ package tasks
 import "github.com/apache/incubator-devlake/plugins/helper"
 
 type AeOptions struct {
-	ProjectId int
-	Tasks     []string `json:"tasks,omitempty"`
+	ConnectionId uint64 `json:"connectionId"`
+	ProjectId    int
 }
 
 type AeTaskData struct {
@@ -29,5 +29,6 @@ type AeTaskData struct {
 	ApiClient *helper.ApiAsyncClient
 }
 type AeApiParams struct {
-	ProjectId int
+	ConnectionId uint64 `json:"connectionId"`
+	ProjectId    int
 }
