@@ -22,17 +22,21 @@ import (
 	"time"
 )
 
-type GithubPullRequestComment struct {
-	GithubId        int `gorm:"primaryKey"`
-	PullRequestId   int `gorm:"index"`
+type GithubPrComment struct {
+	ConnectionId    uint64 `gorm:"primaryKey"`
+	GithubId        int    `gorm:"primaryKey"`
+	PullRequestId   int    `gorm:"index"`
 	Body            string
 	AuthorUsername  string `gorm:"type:varchar(255)"`
 	AuthorUserId    int
+	CommitSha       string `gorm:"type:varchar(255)"`
 	GithubCreatedAt time.Time
 	GithubUpdatedAt time.Time `gorm:"index"`
+	ReviewId        int
+	Type            string `gorm:"index;type:varchar(255)"`
 	common.NoPKModel
 }
 
-func (GithubPullRequestComment) TableName() string {
+func (GithubPrComment) TableName() string {
 	return "_tool_github_pull_request_comments"
 }
