@@ -17,11 +17,11 @@ limitations under the License.
 
 package archived
 
-import (
-	"github.com/apache/incubator-devlake/models/migrationscripts/archived"
-)
+import "github.com/apache/incubator-devlake/models/migrationscripts/archived"
 
 type GitlabTag struct {
+	ConnectionId uint64 `gorm:"primaryKey"`
+
 	Name               string `gorm:"primaryKey;type:varchar(60)"`
 	Message            string
 	Target             string `gorm:"type:varchar(255)"`
