@@ -22,7 +22,9 @@ import (
 	"time"
 )
 
-type GitlabMergeRequestComment struct {
+type GitlabMrComment struct {
+	ConnectionId uint64 `gorm:"primaryKey"`
+
 	GitlabId        int `gorm:"primaryKey"`
 	MergeRequestId  int `gorm:"index"`
 	MergeRequestIid int `gorm:"comment:Used in API requests ex. /api/merge_requests/<THIS_IID>"`
@@ -30,10 +32,11 @@ type GitlabMergeRequestComment struct {
 	AuthorUsername  string `gorm:"type:varchar(255)"`
 	AuthorUserId    int
 	GitlabCreatedAt time.Time
-	Resolvable      bool `gorm:"comment:Is or is not review comment"`
+	Resolvable      bool   `gorm:"comment:Is or is not review comment"`
+	Type            string `gorm:"comment:if type=null, it is normal comment,if type=diffNote,it is diff comment"`
 	common.NoPKModel
 }
 
-func (GitlabMergeRequestComment) TableName() string {
-	return "_tool_gitlab_merge_request_comments"
+func (GitlabMrComment) TableName() string {
+	return "_tool_gitlab_mr_comments"
 }
