@@ -18,21 +18,40 @@ limitations under the License.
 package tasks
 
 import (
+	"fmt"
 	"time"
 
 	"github.com/apache/incubator-devlake/plugins/helper"
+	"github.com/apache/incubator-devlake/plugins/jenkins/models"
+	"github.com/mitchellh/mapstructure"
 )
 
+type JenkinsApiParams struct {
+	ConnectionId uint64
+}
+
 type JenkinsOptions struct {
-	Host     string
-	Username string
-	Password string
-	Since    string
-	Tasks    []string `json:"tasks,omitempty"`
+	ConnectionId uint64 `json:"connectionId"`
+	Since        string
+	Tasks        []string `json:"tasks,omitempty"`
 }
 
 type JenkinsTaskData struct {
-	Options   *JenkinsOptions
-	ApiClient *helper.ApiAsyncClient
-	Since     *time.Time
+	Options    *JenkinsOptions
+	ApiClient  *helper.ApiAsyncClient
+	Connection *models.JenkinsConnection
+	Since      *time.Time
+}
+
+func DecodeAndValidateTaskOptions(options map[string]interface{}) (*JenkinsOptions, error) {
+	var op JenkinsOptions
+	err := mapstructure.Decode(options, &op)
+	if err != nil {
+		return nil, err
+	}
+	// find the needed Jenkins now
+	if op.ConnectionId == 0 {
+		return nil, fmt.Errorf("connectionId is invalid")
+	}
+	return &op, nil
 }
