@@ -26,11 +26,11 @@ type TapdIterationTask struct {
 	common.NoPKModel
 	ConnectionId uint64 `gorm:"primaryKey"`
 	IterationId  uint64 `gorm:"primaryKey"`
-	WorkspaceID  uint64 `gorm:"primaryKey"`
+	WorkspaceId  uint64 `gorm:"primaryKey"`
 
 	TaskId          uint64 `gorm:"primaryKey"`
-	ResolutionDate  helper.CSTTime
-	TaskCreatedDate helper.CSTTime
+	ResolutionDate  *helper.CSTTime
+	TaskCreatedDate *helper.CSTTime
 }
 
 func (TapdIterationTask) TableName() string {
