@@ -23,13 +23,13 @@ import (
 )
 
 type TapdStoryCategory struct {
-	ConnectionId uint64         `gorm:"primaryKey"`
-	ID           uint64         `gorm:"primaryKey;type:BIGINT" json:"id,string"`
-	Name         string         `json:"name" gorm:"type:varchar(255)"`
-	Description  string         `json:"description"`
-	ParentID     uint64         `json:"parent_id,string"`
-	Created      helper.CSTTime `json:"created"`
-	Modified     helper.CSTTime `json:"modified"`
+	ConnectionId uint64          `gorm:"primaryKey"`
+	Id           uint64          `gorm:"primaryKey;type:BIGINT" json:"id,string"`
+	Name         string          `json:"name" gorm:"type:varchar(255)"`
+	Description  string          `json:"description"`
+	ParentId     uint64          `json:"parent_id,string"`
+	Created      *helper.CSTTime `json:"created"`
+	Modified     *helper.CSTTime `json:"modified"`
 	common.NoPKModel
 }
 
