@@ -21,7 +21,7 @@ import "github.com/apache/incubator-devlake/models/common"
 
 type TapdStoryStatus struct {
 	ConnectionId uint64 `gorm:"primaryKey"`
-	WorkspaceID  uint64 `gorm:"primaryKey"`
+	WorkspaceId  uint64 `gorm:"primaryKey"`
 	EnglishName  string `gorm:"primaryKey;type:varchar(255)"`
 	ChineseName  string
 	IsLastStep   bool
