@@ -22,7 +22,7 @@ import (
 	"time"
 )
 
-// Return defaultValue if text is empty, or try to convert it to int
+// StrToIntOr Return defaultValue if text is empty, or try to convert it to int
 func StrToIntOr(text string, defaultValue int) (int, error) {
 	if text == "" {
 		return defaultValue, nil
@@ -30,10 +30,18 @@ func StrToIntOr(text string, defaultValue int) (int, error) {
 	return strconv.Atoi(text)
 }
 
-// Return defaultValue if text is empty, or try to convert it to time.Duration
+// StrToDurationOr Return defaultValue if text is empty, or try to convert it to time.Duration
 func StrToDurationOr(text string, defaultValue time.Duration) (time.Duration, error) {
 	if text == "" {
 		return defaultValue, nil
 	}
 	return time.ParseDuration(text)
 }
+
+// StrToBoolOr Return defaultValue if text is empty, or try to convert it to bool
+func StrToBoolOr(text string, defaultValue bool) (bool, error) {
+	if text == "" {
+		return defaultValue, nil
+	}
+	return strconv.ParseBool(text)
+}
